import { makeOfflineTransport } from '@sentry/core';
import { makeElectronTransport } from './electron-net.js';
import { createOfflineStore } from './offline-store.js';

/**
 * Creates a Transport that uses Electrons net module to send events to Sentry. When they fail to send they are
 * persisted to disk and sent later
 */
function makeElectronOfflineTransport(baseTransport = makeElectronTransport) {
    return (userOptions) => {
        // `makeElectronOfflineTransport` is a combination of two transports.
        //
        // The base Electron transport (`makeElectronTransport`) is wrapped by `makeOfflineTransport` which stores events to
        // disk when they fail to send.
        return makeOfflineTransport(baseTransport)({
            flushAtStartup: true,
            createStore: createOfflineStore,
            ...userOptions,
        });
    };
}

export { makeElectronOfflineTransport };
//# sourceMappingURL=electron-offline-net.js.map
